@@ -1,7 +1,4 @@
-from .gui2html import *
-
-Label = _Label
-Button = _Button
+from .gui import *
 __all__ = [
     'Label',
     'create',
